@@ -56,12 +56,12 @@ class SpellingManager(BulkManager):
 #        return u'%s' % (self.Label,)
 
 class SyntacticCategory(models.Model):
-    Label = models.CharField(max_length=50)
-    Description = models.CharField(max_length=100,blank=True,null=True)
-    CategoryType = models.CharField(max_length=100,blank=True,null=True)
+    label = models.CharField(max_length=50)
+    description = models.CharField(max_length=100,blank=True,null=True)
+    categoryType = models.CharField(max_length=100,blank=True,null=True)
 
     def __unicode__(self):
-        return self.Label
+        return self.label
 
 
 #class CatRelationship(models.Model):
@@ -74,15 +74,15 @@ class SyntacticCategory(models.Model):
 
 
 class Transcription(models.Model):
-    Transcription = models.CharField(max_length=250)
-    StressPattern = models.CharField(max_length=100,blank=True,null=True)
-    CVSkel = models.CharField(max_length=100,blank=True,null=True)
+    transcription = models.CharField(max_length=250)
+    stress_pattern = models.CharField(max_length=100,blank=True,null=True)
+    cvskel = models.CharField(max_length=100,blank=True,null=True)
 
     def __unicode__(self):
-        return self.Transcription
+        return self.transcription
 
-    def stripTranscription(self):
-        return self.Transcription.replace('-','').replace("'",'').replace('"','')
+    def strip_transcription(self):
+        return self.transcription.replace('-','').replace("'",'').replace('"','')
 
     #def getCVStruct(self):
     #    if self.CVSkel is not None:
@@ -98,40 +98,49 @@ class Transcription(models.Model):
     #    return cvstruct
 
 class Orthography(models.Model):
-    Spelling = models.CharField(max_length=250)
+    spelling = models.CharField(max_length=250)
 
     def __unicode__(self):
-        return self.Spelling
+        return self.spelling
+
+class SpelledAs(models.Model):
+    word_form = models.ForeignKey('WordForm')
+    orthography = models.ForeignKey(Orthography)
+    frequency = models.FloatField(blank=True,null=True)
+
+class PronouncedAs(models.Model):
+    word_form = models.ForeignKey('WordForm')
+    transcription = models.ForeignKey(Transcription)
 
 class WordForm(models.Model):
-    Lemma = models.ForeignKey('Lemma')
-    Orthographies = models.ManyToManyField(Orthography)
-    Transcriptions = models.ManyToManyField(Transcription)
-    Frequency = models.FloatField(blank=True,null=True)
+    lemma = models.ForeignKey('Lemma')
+    orthographies = models.ManyToManyField(Orthography,through = 'SpelledAs')
+    transcriptions = models.ManyToManyField(Transcription,through = 'PronouncedAs')
+    frequency = models.FloatField(blank=True,null=True)
 
-    def getTranscriptions(self):
-        return ".".join(str(t) for t in self.Transcriptions.all())
+    def get_transcriptions(self):
+        return ".".join(str(t) for t in self.transcriptions.all())
 
-    def getSpellings(self):
-        return ", ".join(str(s) for s in self.Orthographies.all())
+    def get_spellings(self):
+        return ", ".join(str(s) for s in self.orthographies.all())
 
     def __unicode__(self):
-        return u'%s' % self.Lemma.Label
+        return u'%s' % self.lemma.label
 
 class Lemma(models.Model):
-    Label = models.CharField(max_length=250)
-    Category = models.ForeignKey(SyntacticCategory)
-    Frequency = models.FloatField(blank=True,null=True)
+    label = models.CharField(max_length=250)
+    category = models.ForeignKey(SyntacticCategory)
+    frequency = models.FloatField(blank=True,null=True)
 
     #objects = WordManager()
     def __unicode__(self):
-        return self.Label
+        return self.label
 
-    def getTranscriptions(self):
-        return ".".join(str(t) for wf in WordForm.objects.filter(Word=self) for t in wf.Transcriptions.all())
+    def get_transcriptions(self):
+        return ".".join(str(t) for wf in WordForm.objects.filter(lemma=self) for t in wf.transcriptions.all())
 
-    def getSpellings(self):
-        return ", ".join(str(s) for wf in WordForm.objects.filter(Word=self) for s in wf.Orthographies.all())
+    def get_spellings(self):
+        return ", ".join(str(s) for wf in WordForm.objects.filter(lemma=self) for s in wf.orthographies.all())
 
     #def getPrimaryCategory(self):
     #    if self.PrimaryCategory is not None:
