@@ -29,8 +29,8 @@ def doReset():
     #wf_job = group(addWFS.si(x) for x in chunk_dict(wfs,10000))
     #spell_job = group(addSpells.si(x) for x in chunks(spells,10000))
     #trans_job = group(addTrans.si(x) for x in chunks(trans,10000))
-    ajob = group([addLemmas.si(lemmas),addSpells.si(spells),addTrans.si(trans)]
-    c2 = (loadCats.si() | ajob | addWFS.si(wfs) | addRelationships.si(wfs))
+    ajob = group([addLemmas.si(lemmas),addSpells.si(spells),addTrans.si(trans)])
+    c2 = (deleteall.si() | loadCats.si() | ajob | addWFS.si(wfs) | addRelationships.si(wfs))
     res = c2()
     res.get()
 
@@ -45,9 +45,17 @@ def loadCats():
             if head is None:
                 head = l
                 continue
-            cats.append(SyntacticCategory(pk=int(l[0]),Label=l[1],Description=l[2],CategoryType=l[3]))
+            cats.append(SyntacticCategory(pk=int(l[0]),label=l[1],description=l[2],categoryType=l[3]))
     SyntacticCategory.objects.bulk_create(cats)
 
+@task()
+def deleteall():
+    WordForm.objects.all().delete()
+    Transcription.objects.all().delete()
+    Orthography.objects.all().delete()
+    Lemma.objects.all().delete()
+    SyntacticCategory.objects.all().delete()
+
 @task()
 def addLemmas(lemmas):
     ls = []
@@ -55,7 +63,7 @@ def addLemmas(lemmas):
         if int(lemmas[key]['CategoryNum']) > 12:
             continue
         cat = SyntacticCategory.objects.get(pk=int(lemmas[key]['CategoryNum']))
-        ls.append(Lemma(pk=int(key),Label=lemmas[key]['Word'],Category=cat,Frequency=int(lemmas[key]['Freq'])))
+        ls.append(Lemma(pk=int(key),label=lemmas[key]['Word'],category=cat,frequency=int(lemmas[key]['Freq'])))
     Lemma.objects.bulk_create(ls)
 
 def loadLemmas():
@@ -73,12 +81,18 @@ def loadWF():
 
 @task()
 def addRelationships(wfs):
-    wfs = WordForm.objects.all()
-    for w in wfs:
-        ss = list(Orthography.objects.filter(Spelling__in = wfs[str(w.pk)]['Spellings']))
-        w.Orthographies.add(*ss)
-        ts = list(Transcription.objects.filter(Transcription__in = wfs[str(w.pk)]['Transcriptions']))
-        w.Transcriptions.add(*ts)
+    wf = WordForm.objects.all()
+    pas = []
+    sas = []
+    for w in wf:
+        for s in wfs[str(w.pk)]['Spellings']:
+            spell = Orthography.objects.get(spelling = s[0])
+            sas.append(SpelledAs(word_form=w,orthography=spell,frequency=s[1]))
+        for t in wfs[str(w.pk)]['Transcriptions']:
+            pron = Transcription.objects.get(transcription = t)
+            sas.append(PronouncedAs(word_form=w,transcription=pron))
+    SpelledAs.objects.bulk_create(sas)
+    PronouncedAs.objects.bulk_create(pas)
 
 @task()
 def addWFS(wfs):
@@ -87,17 +101,17 @@ def addWFS(wfs):
         lem = Lemma.objects.filter(pk=int(wfs[key]['IdLemma']))
         if len(lem) != 1:
             continue
-        wfss.append(WordForm(pk=int(wfs[key]),Lemma = lem[0],Frequency = int(wfs[key]['Freq'])))
+        wfss.append(WordForm(pk=int(key),lemma = lem[0],frequency = int(wfs[key]['Freq'])))
     WordForm.objects.bulk_create(wfss)
 
 @task()
 def addSpells(spells):
-    ss = [Orthography(pk=s[0],Spelling = s[1]) for s in spells]
+    ss = [Orthography(pk=s[0],spelling = s[1]) for s in spells]
     Orthography.objects.bulk_create(ss)
 
 @task()
 def addTrans(trans):
-    ts = [Transcription(pk=t[0],Transcription = t[1]) for t in trans]
+    ts = [Transcription(pk=t[0],transcription = t[1]) for t in trans]
     Transcription.objects.bulk_create(ts)
 
 
@@ -112,12 +126,12 @@ def loadOrthLemmas():
                 continue
             main = l[:8]
             additional = l[8:]
-            spellings = [l[1]]
+            #spellings = [l[1]]
             nl = {'Word':l[1],'Freq':l[2]}
-            if len(additional) != 0:
-                additional = chunks(additional,4)
-                spellings.extend([re.sub(r'-(?!-)',r'',x[3]) for x in additional])
-            nl['Spellings'] = set(spellings)
+            #if len(additional) != 0:
+            #    additional = chunks(additional,4)
+            #    spellings.extend([re.sub(r'-(?!-)',r'',x[3]) for x in additional])
+            #nl['Spellings'] = set(spellings)
             lemmas[l[0]] = nl
     return lemmas
 
@@ -134,7 +148,7 @@ def addCategories(lemmas):
     return lemmas
 
 def loadOrthWF():
-    ss = []
+    ss = set([])
     wfs = {}
     with open(fetch_celex_resource('Orthography/celex-orthography-wordforms.txt'),'r') as f:
         head = None
@@ -145,18 +159,18 @@ def loadOrthWF():
                 continue
             main = l[:9]
             additional = l[9:]
-            spellings = [l[1]]
+            spellings = [(main[1],main[6])]
             nl = {'IdLemma':l[3],'Freq':l[2]}
             if len(additional) != 0:
                 additional = chunks(additional,5)
-                spellings.extend([x[1] for x in additional])
+                spellings.extend([(x[0],x[2]) for x in additional])
             nl['Spellings'] = set(spellings)
-            ss.extend(spellings)
+            ss.update([x[0] for x in nl['Spellings']])
             wfs[main[0]] = nl
     return wfs,ss
 
 def loadTransWF(wfs):
-    ts = []
+    ts = set([])
     with open(fetch_celex_resource('Phonology/celex-phonology-wordforms.txt'),'r') as f:
         head = None
         for line in f:
@@ -171,7 +185,7 @@ def loadTransWF(wfs):
                 additional = chunks(additional,4)
                 trans.extend([x[1] for x in additional])
             wfs[main[0]]['Transcriptions'] = set(trans)
-            ts.extend(trans)
+            ts.update(trans)
     return wfs,ts
 
 #def loadTransLemmas(lemmas):
