@@ -74,26 +74,26 @@ def string_selection(request):
             response['Content-Disposition'] = 'attachment; filename="strings.csv"'
             writer = csv.writer(response)
             qs = WordForm.objects.all()
-            qs = qs.filter(Lemma__Category__in = form.cleaned_data['categories']).prefetch_related()
+            qs = qs.filter(lemma__category__in = form.cleaned_data['categories']).prefetch_related()
             if form.cleaned_data['exclude_punctuation']:
-                qs = qs.exclude(Orthographies__Spelling__contains="'")
-                qs = qs.exclude(Orthographies__Spelling__contains=".")
-                qs = qs.exclude(Orthographies__Spelling__contains=",")
-                qs = qs.exclude(Orthographies__Spelling__contains='"')
+                qs = qs.exclude(orthographies__spelling__contains="'")
+                qs = qs.exclude(orthographies__spelling__contains=".")
+                qs = qs.exclude(orthographies__spelling__contains=",")
+                qs = qs.exclude(orthographies__spelling__contains='"')
             if form.cleaned_data['exclude_titlecase']:
-                qs = qs.exclude(Orthographies__Spelling__regex="^[A-Z]")
+                qs = qs.exclude(orthographies__spelling__regex="^[A-Z]")
             #if form.cleaned_data['phone_length'] != '0':
             #    qs = filter(lambda q: len(q.Transcriptions.
-            qs = qs.filter(Transcriptions__CVSkel = forms.cleaned_data['cvskel'])
+            qs = qs.filter(transcriptions__cvskel = forms.cleaned_data['cvskel'])
             for q in qs:
-                if len(q.Transcriptions.all()) != 1:
+                if len(q.transcriptions.all()) != 1:
                     continue
-                t = q.Transcriptions.all()[0]
-                s = q.Orthographies.all()[0]
-                f = q.Frequency
-                c = q.Lemma.Category.Label
-                L = q.Lemma.Label
-                LF = q.Lemma.Frequency
+                t = q.transcriptions.all()[0]
+                s = q.orthographies.all()[0]
+                f = q.frequency
+                c = q.lemma.category.label
+                L = q.lemma.label
+                LF = q.lemma.frequency
                 writer.writerow([s,t,c,f,L,LF])
             return response
     form = StringForm()
